==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/cpptools/cppmodelmanagersupportinternal.cpp <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "cppcompletionassist.h"
#include "cpphighlightingsupportinternal.h"
#include "cppmodelmanagersupportinternal.h"

#include <QCoreApplication>

using namespace CppTools;
using namespace CppTools::Internal;

ModelManagerSupportInternal::ModelManagerSupportInternal()
    : m_completionAssistProvider(new InternalCompletionAssistProvider)
{
}

ModelManagerSupportInternal::~ModelManagerSupportInternal()
{
}

QString ModelManagerSupportInternal::id() const
{
    return QLatin1String("CppTools.BuiltinCodeModel");
}

QString ModelManagerSupportInternal::displayName() const
{
    return QCoreApplication::translate("ModelManagerSupportInternal::displayName",
                                       "Qt Creator Built-in");
}

CppCompletionAssistProvider *ModelManagerSupportInternal::completionAssistProvider()
{
    return m_completionAssistProvider.data();
}

CppHighlightingSupport *ModelManagerSupportInternal::highlightingSupport(TextEditor::ITextEditor *editor)
{
    return new CppHighlightingSupportInternal(editor);
}

==> qt-creator-opensource-src-3.3.0.zip: qt-creator-opensource-src-3.3.0/src/plugins/cpptools/cppmodelmanagersupportinternal.cpp <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "cppcompletionassist.h"
#include "cppmodelmanagersupportinternal.h"
#include "builtineditordocumentprocessor.h"

#include <QCoreApplication>

using namespace CppTools;
using namespace CppTools::Internal;

ModelManagerSupportInternal::ModelManagerSupportInternal()
    : m_completionAssistProvider(new InternalCompletionAssistProvider)
{
}

ModelManagerSupportInternal::~ModelManagerSupportInternal()
{
}

QString ModelManagerSupportInternal::id() const
{
    return QLatin1String("CppTools.BuiltinCodeModel");
}

QString ModelManagerSupportInternal::displayName() const
{
    return QCoreApplication::translate("ModelManagerSupportInternal::displayName",
                                       "Qt Creator Built-in");
}

BaseEditorDocumentProcessor *ModelManagerSupportInternal::editorDocumentProcessor(
        TextEditor::TextDocument *baseTextDocument)
{
    return new BuiltinEditorDocumentProcessor(baseTextDocument);
}

CppCompletionAssistProvider *ModelManagerSupportInternal::completionAssistProvider()
{
    return m_completionAssistProvider.data();
}
